@protocol IO2GTradingSettingsProvider <IAddRef>

    /** Gets condition distance for the stop. */
    - (int) getCondDistStopForTrade: (NSString*) instrument;

    /** Gets condition distance for the limit. */
    - (int) getCondDistLimitForTrade: (NSString*) instrument;

    /** Gets condition distance for the entry stop. */
    - (int) getCondDistEntryStop: (NSString*) instrument;

    /** Gets condition distance for the entry limit. */
    - (int) getCondDistEntryLimit: (NSString*) instrument;

    /** Gets minimum quantity (in lots) for an order for specified instrument and account. */
    - (int) getMinQuantity: (NSString*) instrument :(id<IO2GAccountRow>) account;

    /** Gets maximum quantity (in lots) for an order for specified instrument and account. */
    - (int) getMaxQuantity: (NSString*) instrument :(id<IO2GAccountRow>) account;

    /** Gets base unit size by the account identifier and instrument identifier. */
    - (int) getBaseUnitSize: (NSString*) instrument :(id<IO2GAccountRow>) account;

    /** Gets marker status. */
    - (O2GMarketStatus) getMarketStatus: (NSString*) instrument;

    /** Gets minimal trailing step. */
    - (int) getMinTrailingStep;

    /** Gets maximal trailing step. */
    - (int) getMaxTrailingStep;

    /** Gets the MMR for the specified instrument by account. */
    - (double) getMMR: (NSString*) instrument :(id<IO2GAccountRow>) account;

    /** Gets the MMR/LMR/EMR for the specified instrument by account.

        @param  instrument      Instrument.
        @param  account         Account row.
        @param  mmr             [out] MMR.
        @param  emr             [out] EMR.
        @param  lmr             [out] LMR.

        @return Whether three level margin is used.
    */
    - (BOOL) getMargins: (NSString*) instrument :(id<IO2GAccountRow>) account :(double*) mmr :(double*) emr :(double*) lmr;

@end
